"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var power_assert_1 = __importDefault(require("power-assert"));
var path_1 = __importDefault(require("path"));
var kernel_1 = require("@textlint/kernel");
var fs_1 = __importDefault(require("fs"));
var org_to_ast_1 = require("../src/org-to-ast");
var index_1 = __importDefault(require("../src/index"));
describe('OrgProcessor-test', function () {
    describe('#parse', function () {
        it('should return AST', function () {
            var result = org_to_ast_1.parse("\nThis is text.\n      ");
            power_assert_1.default(result.type === 'Document');
        });
        it('heading should Header', function () {
            var result = org_to_ast_1.parse("\n** Heading\n      ");
            var section = result.children[0];
            var header = section.children[0];
            power_assert_1.default.equal(header.type, 'Header');
        });
        it('list item should List', function () {
            var result = org_to_ast_1.parse("\n- List item\n      ");
            var list = result.children[0];
            var listItem = list.children[0];
            power_assert_1.default.equal(list.type, 'List');
            power_assert_1.default.equal(listItem.type, 'ListItem');
        });
        it('horizontal should HorizontalDef', function () {
            var result = org_to_ast_1.parse("\n-----\n      ");
            var target = result.children[0];
            power_assert_1.default.equal(target.type, 'HorizontalRule');
        });
        it('begin_src should CodeBlock', function () {
            var result = org_to_ast_1.parse("\n#+begin_src\n  const a = 1;\n#+end_src\n      ");
            var target = result.children[0];
            power_assert_1.default.equal(target.type, 'CodeBlock');
        });
        it('begin_comment should Codeblock', function () {
            var result = org_to_ast_1.parse("\n#+begin_comment\n  This is comment.\n#+end_comment\n      ");
            var target = result.children[0];
            power_assert_1.default.equal(target.type, 'CodeBlock');
        });
        it('begin_quote should Codeblock', function () {
            var result = org_to_ast_1.parse("\n#+begin_quote\n  This is quote.\n#+end_quote\n      ");
            var target = result.children[0];
            power_assert_1.default.equal(target.type, 'CodeBlock');
        });
        it('text should Paragraph', function () {
            var result = org_to_ast_1.parse("\nThis is text.\n      ");
            var target = result.children[0];
            power_assert_1.default.equal(target.type, 'Paragraph');
        });
        // inline
        it('inline text should Str', function () {
            var result = org_to_ast_1.parse("\nThis is text.\n      ");
            var paragraph = result.children[0];
            var text = paragraph.children[0];
            power_assert_1.default.equal(text.type, 'Str');
        });
        it('inline code should Code', function () {
            var result = org_to_ast_1.parse("\n~const a = 1;~\n      ");
            var paragraph = result.children[0];
            var code = paragraph.children[0];
            power_assert_1.default.equal(code.type, 'Code');
        });
        it('emphasis text should Emphasis', function () {
            var result = org_to_ast_1.parse("\n*This is text.*\n      ");
            var paragraph = result.children[0];
            var emphasis = paragraph.children[0];
            power_assert_1.default.equal(emphasis.type, 'Emphasis');
        });
        it('link should Link', function () {
            var result = org_to_ast_1.parse("\n[[http://example.com/][Example Domain]]\n      ");
            var paragraph = result.children[0];
            var link = paragraph.children[0];
            power_assert_1.default.equal(link.type, 'Link');
            power_assert_1.default.equal(link.url, 'http://example.com/');
        });
        it('footnote should FootnoteReference', function () {
            var result = org_to_ast_1.parse("\n[fn:1] This is a footnote\n      ");
            var target = result.children[0];
            power_assert_1.default.equal(target.type, 'FootnoteReference');
        });
    });
    var lintFile = function (filePath, options) {
        if (options === void 0) { options = true; }
        var kernel = new kernel_1.TextlintKernel();
        var text = fs_1.default.readFileSync(filePath, 'utf-8');
        return kernel.lintText(text, {
            filePath: filePath,
            ext: '.org',
            plugins: [
                {
                    pluginId: 'org',
                    plugin: index_1.default,
                    options: options,
                },
            ],
            rules: [{ ruleId: 'textlint-rule-max-comma', rule: require('textlint-rule-max-comma').default }], // eslint-disable-line
        });
    };
    describe('OrgPlugin', function () {
        describe('when target file is a Org', function () {
            it('should report lint error', function () {
                var fixturePath = path_1.default.join(__dirname, '/fixtures/lint-error.org'); // eslint-disable-line
                return lintFile(fixturePath).then(function (results) {
                    power_assert_1.default(results.messages.length > 0);
                    power_assert_1.default(results.filePath === fixturePath);
                });
            });
            it('should not comma check inside the code block.', function () {
                var fixturePath = path_1.default.join(__dirname, '/fixtures/codeblock-test.org'); // eslint-disable-line
                return lintFile(fixturePath).then(function (results) {
                    power_assert_1.default(results.messages.length === 0);
                });
            });
        });
    });
});
